@@ -1,16 +1,21 @@
       subroutine back(TT,r,k,ns,l,S,Psi,Piv,PI,Phi,LL,U,V)
 
-      integer t,TT,j,r,i,ns,l,c,k,S(ns,TT,r)
-      double precision Psi(l,k,r),Phi(ns,k,TT)
-      double precision Piv(ns,k),LL(ns,k,TT),PI(k,k,ns,TT)
+      integer t,TT,i,ns,c,k
+      double precision Phi(ns,k,TT)
+      double precision LL(ns,k,TT),PI(k,k,ns,TT)
       double precision U(k,k,ns,TT),V(ns,k,TT),pv(ns)
       double precision M(ns,k),M0(ns,k),pm(k)
-      
+      l = l
+      piv = piv
+      psi = psi
+      r = r
+      s = s
+
 c compute marginal probabilities
       pv = 0
       do i=1,ns
         pv(i) = sum(LL(i,:,TT))
-      end do      
+      end do
 c compute backward probabilities
 c last time occasion
       M = 1
@@ -18,7 +23,7 @@ c last time occasion
         V(i,:,TT) = LL(i,:,TT)/pv(i)
         pm = Phi(i,:,TT)
         do c=1,k
-          U(c,:,i,TT) = LL(i,c,TT-1)*(PI(c,:,i,TT)*pm)/pv(i) 	  
+          U(c,:,i,TT) = LL(i,c,TT-1)*(PI(c,:,i,TT)*pm)/pv(i)
         end do
       end do
 c for the previous occasions
@@ -32,13 +37,13 @@ c for the previous occasions
           if(t>1) then
             pm = Phi(i,:,t)*M(i,:)
             do c=1,k
-              U(c,:,i,t) = LL(i,c,t-1)*(PI(c,:,i,t)*pm)/pv(i) 	  
+             U(c,:,i,t) = LL(i,c,t-1)*(PI(c,:,i,t)*pm)/pv(i)
             end do
           end if
         end do
       end do
 
-      end 
+      end
 
 
 
